DjangoplicityCandidateInput
===========================

.. currentmodule:: toasty.pipeline.djangoplicity

.. autoclass:: DjangoplicityCandidateInput
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DjangoplicityCandidateInput.get_unique_id
      ~DjangoplicityCandidateInput.save

   .. rubric:: Methods Documentation

   .. automethod:: get_unique_id
   .. automethod:: save
